==> schemacrawler-14.21.01-sources.jar: schemacrawler/schema/Procedure.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2018, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package schemacrawler.schema;


import java.util.List;
import java.util.Optional;

/**
 * Represents a database procedure.
 *
 * @author Sualeh Fatehi
 */
public interface Procedure
  extends Routine
{

  /**
   * Gets the list of columns in ordinal order.
   *
   * @return Columns of the procedure
   */
  @Override
  List<ProcedureColumn> getColumns();

  /**
   * Gets the procedure type.
   *
   * @return Procedure type
   */
  @Override
  ProcedureReturnType getReturnType();

  /**
   * Gets a column by unqualified name.
   *
   * @param name
   *        Name
   * @return Column of the procedure
   */
  @Override
  Optional<? extends ProcedureColumn> lookupColumn(String name);

}

==> schemacrawler-16.18.2-sources.jar: schemacrawler/schema/Procedure.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2022, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package schemacrawler.schema;

import java.util.List;
import java.util.Optional;

/** Represents a database procedure. */
public interface Procedure extends Routine {

  /**
   * Gets the list of columns in ordinal order.
   *
   * @return Columns of the procedure
   */
  @Override
  List<ProcedureParameter> getParameters();

  /**
   * Gets the procedure type.
   *
   * @return Procedure type
   */
  @Override
  ProcedureReturnType getReturnType();

  /**
   * Gets a column by unqualified name.
   *
   * @param name Name
   * @return Column of the procedure
   */
  @Override
  Optional<? extends ProcedureParameter> lookupParameter(String name);
}
